==> efs-1.60.0-sources.jar: software/amazon/awscdk/services/efs/PosixUser.java <==
package software.amazon.awscdk.services.efs;

/**
 * Represents the PosixUser.
 * <p>
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.234Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.efs.$Module.class, fqn = "@aws-cdk/aws-efs.PosixUser")
@software.amazon.jsii.Jsii.Proxy(PosixUser.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface PosixUser extends software.amazon.jsii.JsiiSerializable {

    /**
     * The POSIX group ID used for all file system operations using this access point.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getGid();

    /**
     * The POSIX user ID used for all file system operations using this access point.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getUid();

    /**
     * Secondary POSIX group IDs used for all file system operations using this access point.
     * <p>
     * Default: - None
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getSecondaryGids() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link PosixUser}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link PosixUser}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<PosixUser> {
        private java.lang.String gid;
        private java.lang.String uid;
        private java.util.List<java.lang.String> secondaryGids;

        /**
         * Sets the value of {@link PosixUser#getGid}
         * @param gid The POSIX group ID used for all file system operations using this access point. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder gid(java.lang.String gid) {
            this.gid = gid;
            return this;
        }

        /**
         * Sets the value of {@link PosixUser#getUid}
         * @param uid The POSIX user ID used for all file system operations using this access point. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder uid(java.lang.String uid) {
            this.uid = uid;
            return this;
        }

        /**
         * Sets the value of {@link PosixUser#getSecondaryGids}
         * @param secondaryGids Secondary POSIX group IDs used for all file system operations using this access point.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder secondaryGids(java.util.List<java.lang.String> secondaryGids) {
            this.secondaryGids = secondaryGids;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link PosixUser}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public PosixUser build() {
            return new Jsii$Proxy(gid, uid, secondaryGids);
        }
    }

    /**
     * An implementation for {@link PosixUser}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements PosixUser {
        private final java.lang.String gid;
        private final java.lang.String uid;
        private final java.util.List<java.lang.String> secondaryGids;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.gid = this.jsiiGet("gid", java.lang.String.class);
            this.uid = this.jsiiGet("uid", java.lang.String.class);
            this.secondaryGids = this.jsiiGet("secondaryGids", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String gid, final java.lang.String uid, final java.util.List<java.lang.String> secondaryGids) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.gid = java.util.Objects.requireNonNull(gid, "gid is required");
            this.uid = java.util.Objects.requireNonNull(uid, "uid is required");
            this.secondaryGids = secondaryGids;
        }

        @Override
        public java.lang.String getGid() {
            return this.gid;
        }

        @Override
        public java.lang.String getUid() {
            return this.uid;
        }

        @Override
        public java.util.List<java.lang.String> getSecondaryGids() {
            return this.secondaryGids;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("gid", om.valueToTree(this.getGid()));
            data.set("uid", om.valueToTree(this.getUid()));
            if (this.getSecondaryGids() != null) {
                data.set("secondaryGids", om.valueToTree(this.getSecondaryGids()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-efs.PosixUser"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            PosixUser.Jsii$Proxy that = (PosixUser.Jsii$Proxy) o;

            if (!gid.equals(that.gid)) return false;
            if (!uid.equals(that.uid)) return false;
            return this.secondaryGids != null ? this.secondaryGids.equals(that.secondaryGids) : that.secondaryGids == null;
        }

        @Override
        public int hashCode() {
            int result = this.gid.hashCode();
            result = 31 * result + (this.uid.hashCode());
            result = 31 * result + (this.secondaryGids != null ? this.secondaryGids.hashCode() : 0);
            return result;
        }
    }
}

==> efs-1.93.0-sources.jar: software/amazon/awscdk/services/efs/PosixUser.java <==
package software.amazon.awscdk.services.efs;

/**
 * (experimental) Represents the PosixUser.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.420Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.efs.$Module.class, fqn = "@aws-cdk/aws-efs.PosixUser")
@software.amazon.jsii.Jsii.Proxy(PosixUser.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface PosixUser extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) The POSIX group ID used for all file system operations using this access point.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getGid();

    /**
     * (experimental) The POSIX user ID used for all file system operations using this access point.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getUid();

    /**
     * (experimental) Secondary POSIX group IDs used for all file system operations using this access point.
     * <p>
     * Default: - None
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getSecondaryGids() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link PosixUser}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link PosixUser}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<PosixUser> {
        private java.lang.String gid;
        private java.lang.String uid;
        private java.util.List<java.lang.String> secondaryGids;

        /**
         * Sets the value of {@link PosixUser#getGid}
         * @param gid The POSIX group ID used for all file system operations using this access point. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder gid(java.lang.String gid) {
            this.gid = gid;
            return this;
        }

        /**
         * Sets the value of {@link PosixUser#getUid}
         * @param uid The POSIX user ID used for all file system operations using this access point. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder uid(java.lang.String uid) {
            this.uid = uid;
            return this;
        }

        /**
         * Sets the value of {@link PosixUser#getSecondaryGids}
         * @param secondaryGids Secondary POSIX group IDs used for all file system operations using this access point.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder secondaryGids(java.util.List<java.lang.String> secondaryGids) {
            this.secondaryGids = secondaryGids;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link PosixUser}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public PosixUser build() {
            return new Jsii$Proxy(gid, uid, secondaryGids);
        }
    }

    /**
     * An implementation for {@link PosixUser}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements PosixUser {
        private final java.lang.String gid;
        private final java.lang.String uid;
        private final java.util.List<java.lang.String> secondaryGids;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.gid = software.amazon.jsii.Kernel.get(this, "gid", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.uid = software.amazon.jsii.Kernel.get(this, "uid", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.secondaryGids = software.amazon.jsii.Kernel.get(this, "secondaryGids", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String gid, final java.lang.String uid, final java.util.List<java.lang.String> secondaryGids) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.gid = java.util.Objects.requireNonNull(gid, "gid is required");
            this.uid = java.util.Objects.requireNonNull(uid, "uid is required");
            this.secondaryGids = secondaryGids;
        }

        @Override
        public final java.lang.String getGid() {
            return this.gid;
        }

        @Override
        public final java.lang.String getUid() {
            return this.uid;
        }

        @Override
        public final java.util.List<java.lang.String> getSecondaryGids() {
            return this.secondaryGids;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("gid", om.valueToTree(this.getGid()));
            data.set("uid", om.valueToTree(this.getUid()));
            if (this.getSecondaryGids() != null) {
                data.set("secondaryGids", om.valueToTree(this.getSecondaryGids()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-efs.PosixUser"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            PosixUser.Jsii$Proxy that = (PosixUser.Jsii$Proxy) o;

            if (!gid.equals(that.gid)) return false;
            if (!uid.equals(that.uid)) return false;
            return this.secondaryGids != null ? this.secondaryGids.equals(that.secondaryGids) : that.secondaryGids == null;
        }

        @Override
        public final int hashCode() {
            int result = this.gid.hashCode();
            result = 31 * result + (this.uid.hashCode());
            result = 31 * result + (this.secondaryGids != null ? this.secondaryGids.hashCode() : 0);
            return result;
        }
    }
}
